@@ -30,7 +30,7 @@
 
 typedef struct {
     int rgb;
-    char *color;
+    const char *color;
 } xpmColorEntry;
 
 /* This is a kind of rgb.txt file */
