@@ -127,7 +127,7 @@ static void invoke_smalltalk_closure(GClosure     *closure,
 
 /* A wrapper around g_signal_connect_closure that looks up the
    selector and creates a Smalltalk GClosure.  */
-static void connect_signal (OOP widget, 
+static int connect_signal (OOP widget, 
 			    char *event_name, 
 			    OOP receiver, 
 			    OOP selector,
@@ -496,21 +496,44 @@ invoke_smalltalk_closure(GClosure     *closure,
     fill_g_value_from_oop (return_value, resultOOP);
 }
 
-/* Signal implementation.  */
-void
+/* Signal implementation */
+int
 connect_signal (OOP widget, 
 		char *event_name, 
 		OOP receiver, 
 		OOP selector,
 		OOP user_data)
 {
-  GtkWidget *cWidget = _blox_vm_proxy->OOPToCObject (widget);
-  GClosure *closure;
+  GtkWidget    *cWidget = _blox_vm_proxy->OOPToCObject (widget);
+  GClosure     *closure;
+  GSignalQuery  qry;
+  guint         sig_id;
+  OOP           oop_sel_args;
 
+  /* Check parameters */
+  if (!G_IS_OBJECT(cWidget)) { return(-1); } /* Invalid widget passed */
+  sig_id = g_signal_lookup(event_name, G_OBJECT_TYPE(G_OBJECT(cWidget)));
+  if (sig_id = 0) { return(-2); } /* Invalid event name */
+
+  g_signal_query(sig_id, &qry);
+  oop_sel_args = _blox_vm_proxy->strMsgSend(selector, "numArgs", NULL);
+  if (oop_sel_args == _blox_vm_proxy->nilOOP) { return(-3); } /* Invalid selector */ 
+
+  /* Check the number of arguments in the selector against the number of 
+     arguments in the event callback */
+  /* We can return fewer arguments than are in the event, if the others aren't 
+     wanted, but we can't return more, and returning nilOOPs instead is not 
+     100% satisfactory, so fail. */
+  if (_blox_vm_proxy->OOPToInt(oop_sel_args) > qry.n_params) { return(-4); }
+
+  /* Receiver is assumed to be OK, no matter what it is */
+  /* Parameters OK, so carry on and connect the signal */
+  
   associate_oop_to_g_object (G_OBJECT (cWidget), widget);
 
   closure = create_smalltalk_closure (receiver, selector, user_data);
   g_signal_connect_closure (cWidget, event_name, closure, FALSE);
+  return(0);
 }
 
 /* Event loop.  */
