@@ -39,6 +39,11 @@
 #include <iconv.h>
 #include <errno.h>
 
+#ifdef WIN32
+# define WIN32_LEAN_AND_MEAN /* avoid including junk */
+# include <windows.h>
+#endif
+
 #define LOCALE_DATA_HEADER \
   OBJ_HEADER; \
   OOP           nameOOP;
