@@ -27,30 +27,8 @@
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
  ***********************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
-#include "gst.h"
 #include "gstpriv.h"
 
-#include <stdio.h>
-#include <fcntl.h>
-
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#if STDC_HEADERS
-#include <stdlib.h>
-#include <string.h>
-#endif /* STDC_HEADERS */
-
-#ifdef HAVE_EXECINFO_H
-#include <execinfo.h>
-#endif
-
-
 /* Define to provide a log of memory allocations on stderr.  */
 /* #define LOG_MEMORY_OPERATIONS */
 
@@ -85,7 +63,7 @@
 static void init_heap (heap_data *h, size_t heap_allocation_size, size_t heap_limit);
 
 /* Oh my God, how broken things sometimes are!  */
-#if defined(__MSVCRT__) && defined small
+#if defined small
 # undef small
 #endif
 
@@ -894,7 +872,7 @@ log_memory (char *op, int n, PTR block)
   k = (long) block;
   i = 18;
   do
-    buf[i--] = (k & 15) < 10 ? (k & 15) + 48 : (k & 15) + 55;
+    buf[i--] = (k & 15) + ((k & 15) < 10 ? '0' : 'a');
   while (k >>= 4);
   buf[i--] = 'x';
   buf[i] = '0';
@@ -904,7 +882,7 @@ log_memory (char *op, int n, PTR block)
       k = (long) n;
       i = 38;
       do
-        buf[i--] = (k % 10) + 48;
+        buf[i--] = (k % 10) + '0';
       while (k /= 10);
     }
 
