@@ -38,7 +38,7 @@
 #else
 # if !defined(alloca)		/* predefined by HP cc +Olibcalls */
 #  ifdef __GNUC__
-#   define alloca __builtin_alloca
+#   define alloca(size) __builtin_alloca(size)
 #  else
 #   if HAVE_ALLOCA_H
 #    include <alloca.h>
