@@ -113,10 +113,6 @@ char *_gst_change_file_name = NULL;
 static int change_str = -1;
 
 
-/* Set by command line flag.  When true, Smalltalk creates FileSegment
-   objects even for files outside the kernel directory. */
-mst_Boolean _gst_store_no_source = false;
-
 /* If true, the normal execution information is supressed, and the
    prompt is emitted with a special marker character ahead of it to
    let the process filter know that the execution has completed. */
@@ -688,33 +684,6 @@ line_stamp (int line)
 }
 
 
-char *
-_gst_get_method_source_from_cur_file (void)
-{
-  char *buf;
-  int endPos, length, startPos;
-
-  /* We have to do an lseek, so we need the real offsets, not the ones
-     that go into FileSegments! */
-  startPos = _gst_get_method_start_pos () - in_stream->fileOffset;
-  endPos = _gst_get_cur_file_pos () - in_stream->fileOffset;
-
-  /* The second -1 removes the terminating '!' */
-  length = endPos - startPos - 1;
-  buf = (char *) xmalloc (length + 1);
-  lseek (in_stream->st_file.fd, startPos, SEEK_SET);
-  _gst_read (in_stream->st_file.fd, buf, length);
-  buf[length] = '\0';
-
-  /* Restore old file position, past the bytes that are still in the
-     buffer. */
-  lseek (in_stream->st_file.fd,
-	 endPos + in_stream->st_file.end - in_stream->st_file.ptr,
-	 SEEK_SET);
-
-  return (buf);
-}
-
 
 int
 _gst_get_cur_file_pos (void)
@@ -799,33 +768,6 @@ _gst_unread_char (int ic)
 }
 
 
-mst_Boolean
-_gst_is_kernel_file (void)
-{
-  char *fullFileName, *fullFileNameTest;
-  mst_Boolean result;
-
-  if (_gst_store_no_source)
-    return (true);
-
-  if ((strcmp (in_stream->fileName, "stdin") == 0)
-      || (_gst_get_method_start_pos () > _gst_get_cur_file_pos ()))
-    return (true);
-
-  fullFileName = fullFileNameTest =
-    _gst_get_full_file_name (in_stream->fileName);
-#if defined(MSDOS) || defined(WIN32) || defined(__OS2__)
-  if (fullFileName[1] == ':')
-    fullFileName += 2;		/* skip over "<drive>:" */
-#endif
-  result = (strstr (fullFileNameTest, KERNEL_PATH) == fullFileNameTest);
-  xfree (fullFileNameTest);
-
-  return (result);
-}
-
-
-
 /* These two are not used, but are provided for additional flexibility. */
 void
 _gst_enable_completion (void)
