@@ -49,10 +49,6 @@ stream_type;
    let the process filter know that the execution has completed. */
 extern mst_Boolean _gst_emacs_process;
 
-/* Set by command line flag.  When true, Smalltalk creates FileSegment
-   objects even for files outside the kernel directory. */
-extern mst_Boolean _gst_store_no_source;
-
 /* Pass file descriptor FD, printed as file name FILENAME, to the
    parser. */
 extern void _gst_push_unix_file (int fd,
@@ -132,9 +128,6 @@ extern void _gst_unread_char (int ic);
 /* Return the next character from the topmost stream in the stack. */
 extern int _gst_next_char (void);
 
-/* Return current method source string from open FileStream */
-extern char *_gst_get_method_source_from_cur_file (void);
-
 /* Return whether the topmost stream is an interactive one. */
 extern mst_Boolean _gst_get_cur_stream_prompt (void) ATTRIBUTE_PURE;
 
@@ -156,10 +149,6 @@ extern int _gst_get_cur_file_pos (void) ATTRIBUTE_PURE;
    of type STREAM_STRING; nil otherwise. */
 extern OOP _gst_get_cur_string (void) ATTRIBUTE_PURE;
 
-/* Return true if current compilation stream is a FileStream
-   associated with a path relative to the kernel directory. */
-extern mst_Boolean _gst_is_kernel_file (void);
-
 #ifdef HAVE_READLINE
 /* Initialize the completion interface for Readline. */
 extern void _gst_initialize_readline (void);
