@@ -86,7 +86,6 @@ static const char help_text[] =
   "\n   -q --quiet --silent\t\t Do not print execution information"
   "\n   -Q --no-messages\t\t Run Smalltalk with -q -g and no startup banner"
   "\n   -r --regression-test\t\t Run in regression test mode, i.e. make\n\t\t\t\t printed messages constant\n"
-  "\n   -s --store-no-source\t\t Don't store source code as Strings for\n\t\t\t\t methods outside the kernel directory\n"
   "\n   -S --snapshot\t\t Save a snapshot just before exiting"
   "\n   -v --version\t\t\t Print the Smalltalk version number and exit"
   "\n   -V --verbose\t\t\t Print names of loaded files and execution stats"
@@ -677,10 +676,6 @@ load_standard_files (void)
 {
   const char **fileNames;
   char fullFileName[MAXPATHLEN];
-  mst_Boolean willStoreNoSource;
-
-  willStoreNoSource = _gst_store_no_source;
-  _gst_store_no_source = true;
 
   _gst_use_undeclared++;
   for (fileNames = standard_files; *fileNames; fileNames++)
@@ -695,8 +690,6 @@ load_standard_files (void)
 	}
     }
   _gst_use_undeclared--;
-
-  _gst_store_no_source = willStoreNoSource;
   return 0;
 }
 
@@ -869,7 +862,7 @@ parse_args (int argc,
 	  _gst_regression_testing = true;
 	  break;
 	case 's':
-	  _gst_store_no_source = true;
+	  /* _gst_store_no_source = true;  always enabled, will die in 2.2 */
 	  break;
 	case 'S':
 	  snapshot_after_load = true;
