@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2003
  * Free Software Foundation, Inc.
  * Written by Steve Byrne and Paolo Bonzini.
  *
@@ -1721,11 +1721,11 @@ scanned_fields_in (mst_Object object,
 
   if COMMON (flags & F_CONTEXT)
     {
-      gst_method_context ctx;
+      gst_method_context context;
       long methodSP;
-      ctx = (gst_method_context) object;
-      methodSP = TO_INT (ctx->spOffset);
-      return ctx->contextStack + methodSP + 1 - &ctx->objClass;
+      context = (gst_method_context) object;
+      methodSP = TO_INT (context->spOffset);
+      return context->contextStack + methodSP + 1 - &context->objClass;
     }
   else
     {
@@ -2031,14 +2031,15 @@ _gst_mark_an_oop_internal (OOP oop,
 	  objClass = object->objClass;
 	  if UNCOMMON (oop->flags & F_CONTEXT)
 	    {
-	      gst_method_context ctx;
+	      gst_method_context context = (gst_method_context) object;
 	      long methodSP;
-	      ctx = (gst_method_context) object;
-	      methodSP = TO_INT (ctx->spOffset);
+
+	      context = (gst_method_context) object;
+	      methodSP = TO_INT (context->spOffset);
 	      /* printf("setting up for loop on context %x, sp = %d\n", 
-	         ctx, methodSP); */
-	      TAIL_MARK_OOPRANGE (&ctx->objClass,
-				  ctx->contextStack + methodSP + 1);
+	         context, methodSP); */
+	      TAIL_MARK_OOPRANGE (&context->objClass,
+				  context->contextStack + methodSP + 1);
 
 	    }
 	  else if UNCOMMON (oop->flags & (F_EPHEMERON | F_WEAK))
