@@ -29,12 +29,8 @@
  *
  ***********************************************************************/
 
-#include "gst.h"
 #include "gstpriv.h"
 
-#include <obstack.h>
-#include <stdio.h>
-
 char *_gst_nil_name = "(nil)";	/* how to print nil */
 
 
