@@ -140,10 +140,10 @@
 	POPLr(rd),				\
 	TESTLrr(aux, aux),			\
 	POPLr(aux),				\
-	JSSm(_jit.pc + 11, 0, 0, 0),		\
+	JSSm(_jit.x.pc + 11, 0, 0, 0),		\
 	ADDLir(0x7FFFFFFF, aux),	/* 6 */	\
 	SBBLir(0, rd),			/* 3 */ \
-	JMPSm(_jit.pc + 10, 0, 0, 0),	/* 2 */ \
+	JMPSm(_jit.x.pc + 10, 0, 0, 0),	/* 2 */ \
 	TESTLrr(aux, aux),		/* 2 */ \
 	SETGr(jit_reg8(aux)),		/* 3 */ \
 	SHRLir(1, aux),			/* 2 */ \
@@ -163,7 +163,7 @@
 	TESTBir(0x40, _AH),					\
 	MOVBir(0, ((le) & 15) | 0x10),				\
 	MOVBir(0, ((ge) & 15) | 0x10),				\
-	JZSm(_jit.pc + 12, 0, 0, 0),				\
+	JZSm(_jit.x.pc + 12, 0, 0, 0),				\
 	_OO(0xd9e4),			/* ftst */	/* 2 */ \
 	_d16(), _OO(0xdfe0),		/* fnstsw ax */	/* 3 */ \
 	SAHF(),						/* 1 */ \
