@@ -76,8 +76,8 @@ typedef unsigned int jit_insn;
 #define _so	3
 #define _un	3
 
-#define _d16(D)		(_ck_d(16,(_UL(D)-_UL(_jit.pc))) & ~3)
-#define _d26(D)		(_ck_d(26,(_UL(D)-_UL(_jit.pc))) & ~3)
+#define _d16(D)		(_ck_d(16,(_UL(D)-_UL(_jit.x.pc))) & ~3)
+#define _d26(D)		(_ck_d(26,(_UL(D)-_UL(_jit.x.pc))) & ~3)
 
 /* primitive instruction forms [1, Section A.4] */
 
@@ -311,8 +311,7 @@ typedef unsigned int jit_insn;
 
 #define MOVEIri2(R,H,L)			(LISri(R,H), (L ? ORIrri(R,R,L) : 0))
 #define MOVEIri(R,I)			(_siP(16,I) ? LIri(R,I) :	\
-					(_uiP(16,I) ? ORIrri(R,0,I) :	\
-					MOVEIri2(R, _HI(I), _LO(I)) ))
+					MOVEIri2(R, _HI(I), _LO(I)) )
 
 #define SUBIrri(RD,RA,IM)		ADDIrri(RD,RA,-_L((IM)))	/* [1, Section F.2.1] */
 #define SUBISrri(RD,RA,IM)		ADDISrri(RD,RA,-_L((IM)))
@@ -354,12 +353,12 @@ typedef unsigned int jit_insn;
 /* 9 below inverts the branch condition and the branch prediction.
  * This has an incestuous knowledge of the fact that register 26
  * is used as auxiliary!!! */
-#define BC_EXT(A, C, D)  (_siP(16, _UL(D)-_UL(_jit.pc)) \
+#define BC_EXT(A, C, D)  (_siP(16, _UL(D)-_UL(_jit.x.pc)) \
   ? BCiii((A), (C), (D)) \
-  : (BCiii((A)^9, (C), _jit.pc+5), LISri(26,_HI(D)), ORIrri(26,26,_LO(D)), \
+  : (BCiii((A)^9, (C), _jit.x.pc+5), LISri(26,_HI(D)), ORIrri(26,26,_LO(D)), \
      MTLRr(26), BLR() ))
 
-#define B_EXT(D)         (_siP(16, _UL(D)-_UL(_jit.pc)) \
+#define B_EXT(D)         (_siP(16, _UL(D)-_UL(_jit.x.pc)) \
   ? Bi((D)) \
   : (LISri(26,_HI(D)), ORIrri(26,26,_LO(D)), MTLRr(26), BLR()) )
 
