@@ -49,7 +49,7 @@
 
 typedef unsigned int jit_insn;
 
-#define _d30(BD)	((_UL(BD) - _UL(_jit.pc))>>2)
+#define _d30(BD)	((_UL(BD) - _UL(_jit.x.pc))>>2)
 #define _d22(BD)	_ck_d(22, _d30(BD))
 
 #define _HI(I)		(_UL(I) >>     (10))
