@@ -49,7 +49,7 @@ void
 stackoverflow_handler (int emergency, stackoverflow_context_t scp)
 {
   pass++;
-  printf ("stack overflow %d caught.\n", pass);
+  printf ("Stack overflow %d caught.\n", pass);
   sigprocmask (SIG_SETMASK, &mainsigset, NULL);
   sigsegv_leave_handler ();
   longjmp (mainloop, emergency ? -1 : pass);
@@ -95,7 +95,7 @@ main ()
     case -1:
       printf ("emergency exit\n"); exit (1);
     case 0: case 1:
-      printf ("Starting recursion pass %d... ", pass + 1);
+      printf ("Starting recursion pass %d.\n", pass + 1);
       recurse (0);
       printf ("no endless recursion?!\n"); exit (1);
     case 2:
@@ -104,6 +104,7 @@ main ()
       abort ();
     }
 
+  printf ("Test passed.\n");
   exit (0);
 }
 
