@@ -143,7 +143,7 @@ typedef union printf_arg
   uintmax_t pa_u_long_long_int;
   float pa_float;
   double pa_double;
-  snv_long_double pa_long_double;
+  long double pa_long_double;
   const char *pa_string;
   const snv_wchar_t *pa_wstring;
   snv_constpointer pa_pointer;
